@@ -57,7 +57,7 @@ fn main() {
 
     while fltk_app.wait() {
         // Clear the screen to dark red
-        draw_background(&gl);
+        draw_background(&*gl);
 
         let mut state = state.borrow_mut();
         state.input.time = Some(start_time.elapsed().as_secs_f64());
@@ -75,10 +75,9 @@ fn main() {
             state.fuse_output(&mut win, egui_output.platform_output);
             let meshes = egui_ctx.tessellate(egui_output.shapes);
             painter.paint_and_update_textures(
-                &gl,
                 state.canvas_size,
                 state.pixels_per_point(),
-                meshes,
+                &meshes,
                 &egui_output.textures_delta,
             );
             win.swap_buffers();
